# Copyright (c) 2003-2004 Chalmers University of Technology
# Authors: Jean-Marc Orliaguet <jmo@ita.chalmers.se>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#

__author__ = "Jean-Marc Orliaguet <jmo@ita.chalmers.se>"

"""
  Portal Box
"""

from Globals import InitializeClass
from AccessControl import ClassSecurityInfo
from Products.CMFCore.CMFCorePermissions import View

from BaseTemplet import BaseTemplet
from cpsskins_utils import callAction
from Acquisition import  aq_base

def addPortalBox(dispatcher, id, REQUEST=None, **kw):
    """Add an Portal Box Templet."""
    ob = PortalBox(id, **kw)
    dispatcher._setObject(id, ob)
    if REQUEST is not None:
        url = dispatcher.DestinationURL()
        REQUEST.RESPONSE.redirect('%s/manage_main' % url)

factory_type_information = (
    {'id': 'Portal Box Templet',
     'title': 'Portal box',
     'description': ('_portalbox_templet_description_'),
     'meta_type': 'Portal Box Templet',
     'icon': 'portalbox_templet.gif',
     'product': 'CPSSkins',
     'factory': 'addPortalBox',
     'immediate_view': 'cpsskins_edit_form',
     'filter_content_types': 0,
     'global_allow': 0,
     'actions': BaseTemplet._actions + (),
    },
)

class PortalBox(BaseTemplet):
    """
    Portal Box Templet.
    """
    meta_type = 'Portal Box Templet'
    portal_type = 'Portal Box Templet'

    render_action = 'cpsskins_portalbox'

    security = ClassSecurityInfo()

    _properties = BaseTemplet._properties + (
       {'id': 'title_source', 
        'type': 'selection', 
         'mode': 'w', 
         'label': 'Portal box title source', 
         'select_variable': 'TitleSourceList', 
         'category': 'general',
         'i18n': 1,
       },
       {'id': 'box_title_i18n', 
        'type': 'boolean', 
        'mode': 'w', 
        'label': 'Translate the box title',
        'default': 0, 
        'category': 'general', 
        'visible': 'IfCanTranslateTitleSource'
       },
       {'id': 'content', 
        'type': 'selection', 
        'mode': 'w', 
        'label': 'Portal box content', 
        'select_variable': 'ContentList', 
        'category': 'general',
        'i18n': 1,
       },
       {'id': 'show_action_icons', 
        'type': 'boolean', 
        'mode': 'w', 
        'label': 'Show action icons', 
        'category': 'actions', 
        'visible': 'IfActionsCategory',
        'default': 0
       },
       {'id': 'show_docs', 
        'type': 'boolean', 
        'mode': 'w', 
        'label': 'Show documents in folders', 
        'category': 'folders', 
        'visible': 'IfFoldersCategory',
        'default': 0,
       },
       {'id': 'folder_items_i18n', 
        'type': 'boolean', 
        'mode': 'w', 
        'label': 'Translate folder items',
        'default': 0, 
        'category': 'folders', 
        'visible': 'IfFoldersCategory'
       },
       {'id': 'level', 
        'type': 'int', 
        'mode': 'w', 
        'label': 'Depth level', 
        'category': 'folders', 
        'visible': 'IfFoldersCategory'
       },
       {'id': 'base', 
        'type': 'selection', 
        'mode': 'w', 
        'label': 'Hierarchy base', 
        'category': 'folders', 
        'select_variable': 'cpsskins_listFolderRoots', 
        'visible': 'IfFoldersCategoryAndExistsBase'
       },
       {'id': 'base_path', 
        'type': 'selection', 
        'mode': 'w', 
        'label': 'Base path', 
        'category': 'folders', 
        'select_variable': 'cpsskins_listPaths', 
        'visible': 'IfFoldersCategory'
       },
       {'id': 'boxlayout', 
        'type': 'selection', 
        'mode': 'w', 
        'label': 'Box layout', 
        'category': 'layout', 
        'select_variable': 'BoxLayoutList',
        'i18n': 1,
       },
       {'id': 'action_categories', 
        'type': 'multiple selection', 
        'mode': 'w', 
        'label': 'Action categories', 
        'select_variable': 'cpsskins_listActionCategories', 
        'category': 'actions', 
        'visible': 'IfActionsCategory'
       },
       {'id': 'custom_action_categories', 
        'type': 'lines', 
        'mode': 'w', 
        'label': 'Custom action categories', 
        'category': 'actions', 
        'visible': 'IfActionsCategory'
       },
       {'id': 'invisible_actions', 
        'type': 'lines', 
        'mode': 'w', 
        'label': 'Invisible actions', 
        'category': 'actions', 
        'visible': 'IfActionsCategory'
       },
       {'id': 'orientation', 
        'type': 'selection', 
        'mode': 'w', 
        'label': 'List orientation', 
        'select_variable': 'OrientationList', 
        'category': 'layout',
        'i18n': 1,
       },
       {'id': 'boxshape', 
        'type': 'selection', 
        'mode': 'w', 
        'label': 'Box shape', 
        'select_variable': 'BoxShapesList', 
        'category': 'style', 
        'meta_type': 'Portal Box Shape'
       },
       {'id': 'boxcolor', 
        'type': 'selection', 
        'mode': 'w', 
        'label': 'Box color', 
        'select_variable': 'BoxColorsList', 
        'category': 'style', 
        'meta_type': 'Portal Box Color'
       },
       {'id': 'info', 
        'type': 'text', 
        'mode': 'w', 
        'label': 'Info text', 
        'category': 'info', 
        'visible': 'IfInfoCategory'
       },
    )

    def __init__(self, id,
                       content = 'actions', 
                       level = 0,
                       title_source = 'Templet title',
                       show_action_icons = 0,
                       show_docs = 0,
                       action_categories = ['user', 'global'],
                       custom_action_categories = [],
                       invisible_actions = ['view',],
                       base_path = '/',
                       orientation = 'vertical',
                       boxshape = '', 
                       boxcolor = '', 
                       info = 'Info here',
                       base = [],
                       boxlayout = 'standard',
                       folder_items_i18n = 0,
                       title_source_i18n = 0,
                        **kw):
        apply(BaseTemplet.__init__, (self, id), kw)
        self.content = content
        self.level = level
        self.show_action_icons = show_action_icons
        self.show_docs = show_docs
        self.base_path = base_path
        self.title_source = title_source
        self.action_categories = action_categories
        self.custom_action_categories = custom_action_categories
        self.invisible_actions = invisible_actions
        self.orientation = orientation
        self.boxshape = boxshape
        self.boxcolor = boxcolor
        self.info = info
        self.base = base
        self.boxlayout = boxlayout
        self.folder_items_i18n = folder_items_i18n
        self.title_source_i18n = title_source_i18n

    security.declarePublic('isPortalBox')
    def isPortalBox(self):
        """ This templet is a Portal Box """
           
        return 1


    security.declarePublic('TitleSourceList')
    def TitleSourceList(self):           
        """ Returns a list of contents for this Templet's title"""
                                   
        list = [ 'Templet title', 
                 'Workflow state', 
                 'Username',
                 'Folder title' ]
        return list  


    security.declarePublic('ContentList')
    def ContentList(self):           
        """ Returns a list of contents for this Templet's body"""

        list = [ 'actions', 
                 'folders', 
                 'about', 
                 'login', 
                 'info', 
                 'related', 
                 'recent', 
                 'language' ]
        return list


    security.declarePublic('OrientationList')
    def OrientationList(self):           
        """ Returns a list of orientations for this Templet"""
                                   
        list = [ 'horizontal', 'vertical']
        return list  



    security.declarePublic('BoxLayoutList')
    def BoxLayoutList(self):           
        """ Returns a list of orientations for this Templet"""

        layouts = [ 'standard', 
                    'one_frame', 
                    'notitle', 
                    'no_frames', 
                    'notitle_noframe',
                    'drawer',
                    'drawer_notitle' ]
        return layouts


    security.declarePublic('IfActionsCategory')
    def IfActionsCategory(self):           
        """ Returns true if the box content is set 'actions' """

        if getattr(self, 'content', None) == 'actions':
            return 1


    security.declarePublic('IfFoldersCategory')
    def IfFoldersCategory(self):           
        """ Returns true if the box content is set 'folders' """

        if getattr(self, 'content', None) == 'folders':
            return 1

    security.declarePublic('IfFoldersCategoryAndExistsBase')
    def IfFoldersCategoryAndExistsBase(self):           
        """ Returns true if the box content is set 'folders' 
            and if the folders have a base """

        if not self.IfFoldersCategory():
            return None

        if not self.cpsskins_ifExistsBase():
            return None
        return 1

    security.declarePublic('IfInfoCategory')
    def IfInfoCategory(self):           
        """ Returns true if the box content is set 'info' """
                         
        if getattr(self, 'content', None) == 'info':
            return 1    


    security.declarePublic('IfCanTranslateTitleSource')
    def IfCanTranslateTitleSource(self):           
        """ Returns true if the title source can be translated """
                         
        if getattr(self, 'title_source', None) in \
                                 ['Templet title',
                                  'Folder title']:
            return 1

    security.declarePublic('BoxShapesList')
    def BoxShapesList(self):           
        """ Returns a list of Portal Box Shape styles"""

        tmtool = self.portal_themes
        styles = tmtool.findStylesByContext(category = 'Portal Box Shape', object=self)
        if styles: 
            return styles['title']

    security.declarePublic('BoxColorsList')
    def BoxColorsList(self):           
        """ Returns a list of Portal Box Color styles"""

        tmtool = self.portal_themes
        styles = tmtool.findStylesByContext(category = 'Portal Box Color', object=self)
        if styles: 
            return styles['title']



InitializeClass(PortalBox)

